@@ -8,7 +8,7 @@ use Linux::Prctl::Securebits;
 use Linux::Prctl::CapabilityBoundingSet;
 use Linux::Prctl::CapabilitySet;
 
-our $VERSION = '1.6.0';
+our $VERSION = '1.4.0';
 
 require XSLoader;
 my @noexport = keys %Linux::Prctl::;
@@ -67,9 +67,9 @@ Linux::Prctl - Perl extension for controlling process characteristics
 
 The linux prctl function allows you to control specific characteristics of a
 process' behaviour. Usage of the function is fairly messy though, due to
-limitations in C and linux. This module provides a nice non-messy interface.
-Most of the text in this documentation is based on text from the linux manpages
-prctl(2) and capabilities(7)
+limitations in C and linux. This module provides a nice non-messy python(ic)
+interface. Most of the text in this documentation is based on text from the
+linux manpages prctl(2) and capabilities(7)
 
 Besides prctl, this library also wraps libcap for complete capability handling.
 
@@ -192,16 +192,14 @@ process, assuming other requirements are met (matching uid, wasn't setuid,
 etc). Use pid 0 to disallow all processes. For more details, see
 /etc/sysctl.d/10-ptrace.conf.
 
-This function is only available for kernel 3.4 and newer, or Ubuntu 10.10 and
-newer.
+This is an ubuntu specific call, appearing as of Ubuntu 10.10
 
 =head3 get_ptracer(pid)
 
 Returns the top of the process tree that is allowed to use PTRACE on the
 calling process. See set_ptracer.
 
-This function is only available for kernel 3.4 and newer, or Ubuntu 10.10 and
-newer.
+This is an ubuntu specific call, appearing as of Ubuntu 10.10
 
 =head3 set_seccomp(mode)
 
